% cisucposter.cls
%
% Created by: Alexandre D. Jesus <ajesus@dei.uc.pt>

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cisucposter}

\LoadClass{article}

\RequirePackage{graphicx}
\RequirePackage[labelsep=none,
                font=footnotesize,
                labelfont=bf,
                textformat=empty,
                singlelinecheck=false]{caption}
\RequirePackage[document]{ragged2e}

\RequirePackage{fontspec}

% CHANGEME any math package needs to be required before unicode-math
\RequirePackage{amsmath,amssymb}
\RequirePackage{unicode-math}
\defaultfontfeatures{Scale=2.5}

% CHANGEME if you want you can alter the font size by changing the scale
% argument of these fonts (remember to change above for math as well)
\setmainfont{NotoSerif}[
  Path=fonts/,
  Extension=.ttf,
  UprightFont=*-Regular,
  ItalicFont=*-Italic,
  BoldFont=*-Bold,
  Scale=2.2]
\newfontfamily\titlefont{AkzidenzGroteskBQBdCnd}[
  Path=fonts/,
  Extension=.otf,
  Scale=10]
\newfontfamily\subtitlefont{AkzidenzGroteskBQCnd}[
  Path=fonts/,
  Extension=.ttf,
  Scale=10]
\newfontfamily\authorfont{AkzidenzGroteskBQBdCnd}[
  Path=fonts/,
  Extension=.otf,
  Scale=2.2]
\newfontfamily\emailfont{AkzidenzGroteskBQCnd}[
  Path=fonts/,
  Extension=.ttf,
  Scale=2.2]
\newfontfamily\sectionfont{AkzidenzGroteskBQBold}[
  Path=fonts/,
  Extension=.otf,
  Scale=2.2]

\RequirePackage{setspace}
\setstretch{2.5}

\setlength{\parindent}{0pt}
\setlength{\parskip}{2.2ex}

\RequirePackage{titlesec}
\titleformat{\section}{\sectionfont}{\thesection.}{1em}{}
\titlespacing{\section}{0pt}{0pt}{-2.2ex}
\titleformat{\subsection}{\sectionfont}{\thesubsection.}{1em}{}
\titlespacing{\subsection}{0pt}{0pt}{-2.2ex}

\RequirePackage{multicol}
\setlength{\columnsep}{1.9cm}

% Set geometry
\RequirePackage[a0paper,
                includeheadfoot,
                headheight=12.30cm,
                headsep=0.00cm,
                top=0.5cm,
                footskip=4.35cm,
                bottom=10.9cm,
                lmargin=5.05cm,
                rmargin=5.05cm]{geometry}

\RequirePackage{fancyhdr}
\pagestyle{fancy}
\renewcommand{\headrulewidth}{0pt}
\fancyhead{}
\fancyhead[L]{%
\includegraphics[trim=28 81 0 0, clip=true]{images/cisucposter/cisuc.pdf}}
\fancyfoot{}
\fancyfoot[L]{%
\includegraphics[width=\textwidth]{images/cisucposter/squares.png}\\
\vspace{2.15cm}
\includegraphics[scale=0.345]{images/cisucposter/uc.eps}%
\includegraphics[scale=0.450,trim=14 -9 37 0, clip=true]{images/cisucposter/fct.pdf}%
\includegraphics[scale=1.77,trim=0 -11 0 0, clip=true]{images/cisucposter/cofinanced_by.pdf}}

\RequirePackage[titles]{tocloft}
\cftpagenumbersoff{figure}
\cftpagenumbersoff{table}
\cftsetpnumwidth{0pt}
\cftsetrmarg{0pt}

\renewcommand{\cftloftitlefont}{\sectionfont}
\setlength{\cftbeforeloftitleskip}{0ex}
\setlength{\cftafterloftitleskip}{0pt}
\setlength{\cftfigindent}{0pt}
\settowidth{\cftfignumwidth}{\scriptsize\bfseries Figure 9: }
\renewcommand{\cftfigfont}{\scriptsize}
\renewcommand{\cftfigpresnum}{\bfseries Figure }
\renewcommand{\cftfigaftersnum}{: }
\renewcommand{\cftfigleader}{}
\renewcommand{\listfigurename}{Captions of Figures}

\renewcommand{\cftlottitlefont}{\sectionfont}
\setlength{\cftbeforelottitleskip}{0pt}
\setlength{\cftafterlottitleskip}{0pt}
\setlength{\cfttabindent}{0pt}
\settowidth{\cfttabnumwidth}{\scriptsize\bfseries Table 9: }
\renewcommand{\cfttabfont}{\scriptsize}
\renewcommand{\cfttabpresnum}{\bfseries Table }
\renewcommand{\cfttabaftersnum}{: }
\renewcommand{\cfttableader}{}
\renewcommand{\listtablename}{Captions of Tables}

\endinput
